import discord
from discord.ext import commands

def setupBot(prefix):
    global client
    client = commands.Bot(command_prefix = prefix)


def botPlaying(activity):
    global actv
    actv = activity

def runBot(key):
    @client.event
    async def on_ready():
        print('[LOGS] Bot is ready!')
        print("""[LOGS] Logged in as: {}\n[LOGS] ID: {}""".format(client.user.name, client.user.id))
        try:
            await client.change_presence(activity=discord.Game(name=actv))
        except:
            await client.change_presence(activity=discord.Game(name='Savage Discord'))
    
    client.run(key)


from setuptools import setup, find_packages
 
classifiers = [
  'Development Status :: 1 - Planning',
  'Intended Audience :: Developers',
  'Operating System :: Microsoft :: Windows :: Windows 10',
  'License :: OSI Approved :: MIT License',
  'Programming Language :: Python :: 3'
]
 
setup(
  name='savagediscord',
  version='0.0.1',
  description='For more info, go to: https://github.com/SavageMusicYT/savagediscord',
  long_description=open('README.txt').read() + '\n\n' + open('CHANGELOG.txt').read(),
  url='https://github.com/SavageMusicYT/savagediscord',  
  author='Savage Music',
  author_email='support@savagesmusic.com',
  license='MIT', 
  classifiers=classifiers,
  keywords='discord', 
  packages=find_packages(),
  install_requires=['discord.py'] 
)